@@ -22,11 +22,10 @@ pub struct Kubectl {
 }
 
 impl Kubectl {
-    pub async fn load() -> kube::Result<Self> {
-        let client = kube::Client::try_default().await?;
-        let k8s = Self { client };
-
-        Ok(k8s)
+    pub async fn try_default() -> kube::Result<Self> {
+        kube::Client::try_default()
+            .await
+            .map(|client| Self { client })
     }
 
     pub fn client(&self) -> &kube::Client {
@@ -60,7 +59,7 @@ impl Kubectl {
 
 impl fmt::Debug for Kubectl {
     fn fmt(&self, f: &mut fmt::Formatter<'_>) -> fmt::Result {
-        f.debug_struct("K8s")
+        f.debug_struct("Kubectl")
             .field("client", &"<kube::Client>")
             .finish()
     }
